@@ -1,4 +1,4 @@
-{-# OPTIONS -fglasgow-exts #-}
+{-# LANGUAGE DeriveDataTypeable #-}
 
 module GShow2 (tests) where
 
@@ -10,12 +10,12 @@ output of the program should be some representation of the infamous
 
 -}
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Generics
 import CompanyDatatypes
 
-tests = gshow genCom ~=? output
+tests = gshow genCom @=? output
 
 {-
 
