@@ -1,17 +1,17 @@
-{-# LANGUAGE CPP #-}
-{-# OPTIONS -fglasgow-exts #-}
+{-# LANGUAGE CPP                #-}
+{-# LANGUAGE DeriveDataTypeable #-}
 
 module Newtype (tests) where
 
 -- The type of a newtype should treat the newtype as opaque
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Generics
 
 newtype T = MkT Int deriving( Typeable )
 
-tests = show (typeOf (undefined :: T)) ~?= output
+tests = show (typeOf (undefined :: T)) @?= output
 
 #if __GLASGOW_HASKELL__ >= 701
 output = "T"
