@@ -1,4 +1,4 @@
-{-# OPTIONS -fglasgow-exts #-}
+{-# LANGUAGE DeriveDataTypeable #-}
 
 module Typecase1 (tests) where
 
@@ -10,7 +10,7 @@ Note: we only need Data.Typeable. Say: Dynamics are NOT involved.
 
 -}
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Typeable
 import Data.Maybe
@@ -34,7 +34,7 @@ f a = (maybe (maybe (maybe others
   int a =  "got an int, incremented: " ++ show (a + 1)
 
   -- do something with floats
-  float :: Float -> String
+  float :: Double -> String
   float a = "got a float, multiplied by .42: " ++ show (a * 0.42)
 
   -- do something with my typeables
@@ -49,11 +49,11 @@ f a = (maybe (maybe (maybe others
 -- Test the type case
 --
 tests = ( f (41::Int)
-        , f (88::Float)
+        , f (88::Double)
         , f (MyCons "42")
-        , f True) ~=? output
+        , f True) @=? output
 
 output = ( "got an int, incremented: 42"
          , "got a float, multiplied by .42: 36.96"
          , "got a term: MyCons \"42\""
-         , "got something else: True")
\ No newline at end of file
+         , "got something else: True")
