@@ -1,4 +1,4 @@
-{-# OPTIONS -fglasgow-exts #-}
+{-# LANGUAGE DeriveDataTypeable #-}
 
 module Typecase2 (tests) where
 
@@ -11,7 +11,7 @@ So we only keep a single constraint: the one for class Data.
 
 -}
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Generics
 import Data.Maybe
@@ -35,7 +35,7 @@ f a = (maybe (maybe (maybe others
   int a =  "got an int, incremented: " ++ show (a + 1)
 
   -- do something with floats
-  float :: Float -> String
+  float :: Double -> String
   float a = "got a float, multiplied by .42: " ++ show (a * 0.42)
 
   -- do something with my data
@@ -50,9 +50,9 @@ f a = (maybe (maybe (maybe others
 -- Test the type case
 --
 tests = ( f (41::Int)
-        , f (88::Float)
+        , f (88::Double)
         , f (MyCons "42")
-        , f True) ~=? output
+        , f True) @=? output
 
 output = ( "got an int, incremented: 42"
          , "got a float, multiplied by .42: 36.96"
